#!/usr/bin/perl -w

use strict;
use Cwd;

my $main_dir	= getcwd;
my $main_page	= 'output/index.html';
my $indir	= 'main-articles';				# The input directory name
my $outdir	= 'output';					# The output directory name
my $pagedir	= 'pages';					# Individual pages directory
my $pages_b	= 'pages-b';					# Pages that do not show at menu
my @maint	= qx(cat template/main-top);			# Top section for main page
my @mainb	= qx(cat template/main-bottom);			# Bottom section for main page
my @footer	= qx(cat template/footer);			# Footer for every page incl main
my @paget	= qx(cat template/page-top);			# Top section for every page in pages/
my @pageb	= qx(cat template/page-bottom);			# Bottom section for every page in pages/
my @articlet	= qx(cat template/article-top);			# Top section for every article in main-articles/
my @articleb	= qx(cat template/article-bottom);		# Bottom section for every article in main-articles/
my $previewnum	= 3;						# Article number preview for frontpage
my $cssfile	= 'output/style.css';

unlink glob "output/*.html"; 					# Remove old pages
unlink "output/tmp";						# File which stores menu
open (OUT, '>', "$outdir/index.html") or die $!;		# Create the index.html page
print OUT @maint;

chdir($pagedir) or die "Can't change path to $pagedir $!\n";
print "\n\t\t\tblipper (BLog In PERl) v0.1\n\n";
print "Entering " . getcwd . "\n\n";
open (OUT, '>>', "../$outdir/tmp") or die $!;			# Begin creating menu for individual pages in a file
print OUT "<ul class=\"menu\">"; 				# Begin list for menu items
print OUT "<li><a href=\"index.html\">home</a></li>";

my @pages = <*>;						# Create individual pages
foreach my $page (@pages) {
	print "Generating page: ";
	printf("%-30s", $page);
	my @array = qx(cat $page);
	my $html = qx(Markdown.pl $page);
	$page =~ s/\.[^\.]*$//;
	print "\t==> output page:\t" . "../$outdir/$page.html\n";
	open (OUT, '>', "../$outdir/$page.html") or die $!;
	print OUT @paget;
	print OUT $html;
	print OUT @pageb;
	close OUT;

	open (OUT, '>>', "../$outdir/tmp") or die $!;		# Append page links to tmp file
	print OUT "<li><a href=\"$page.html\">$page</a></li>";
}

print OUT "</ul>";
print OUT "<br>";
close OUT or die $!;

chdir($main_dir) or die "Can't change path to $main_dir $!\n";
# open (OUT, '>>', "$outdir/index.html") or die $!;		# Create the index.html page
# print OUT "<p class=\"latart\">Latest articles:</p>";
# close OUT or die $!;
print "\nIndividual page generation completed. ";
chdir($indir) or die "Can't change path to $indir $!\n";
print "\nEntering " . getcwd . "\n\n";

my @files = <*>;
@files = reverse @files;
my $i = 0;
foreach my $file (@files) {					# Read each file(post) from indir, cat to $outdir/$file.html
	print "Processing file: ";
	printf ("%-30s", $file);
	my $array = qx(cat $file);
	my $html = qx(Markdown.pl $file);
	$file =~ s/\.[^\.]*$//;
	print "\t==> output file:\t" . "../$outdir/$file.html\n";

	open (OUT, '>', "../$outdir/$file.html") or die $!;
	print OUT @articlet;
	print OUT $html;					# Append content
	print OUT @articleb;
	close OUT;

	my @preview_array = split(/\n{2,}/, $html);		# Pull title and first paragraph from article.
	$preview_array[0] =~ s/h1>/h3>/g;			# Change h1 to h3 for the index page.
	$preview_array[0] =~ s/<h3>/<a href=\"$file.html\"><h3>/g;
	$preview_array[0] =~ s/<\/h3>/<\/h3><\/a>/g;

	if ($i < $previewnum) {					# Append links to stories in index.html
		open (OUT, '>>', "../$outdir/index.html") or die $!;
		print OUT "<div class=\"preview\">
				$preview_array[0]
				$preview_array[1]<br>
				$preview_array[2]<br>
				<a class=\"previewlink\" href=\"$file.html\">
				<em>read more... →</em></a></p></div>";
		print OUT "\n";
		print OUT "<br>";
	}
	$i++;
}

chdir($main_dir) or die "Can't change path to $main_dir $!\n";
print "\nArticle generation completed. ";
chdir($pages_b) or die "Can't change path to $indir $!\n";
print "\nEntering " . getcwd . "\n\n";

my @ind_pages = <*>;
foreach my $file (@ind_pages) {					# Read each page that we do not want to add in our menu
	print "Processing pages:";
	printf ("%-30s", $file);
	my @array = qx(cat $file);
	my $html = qx(Markdown.pl $file);			# Markdown to html
	$file =~ s/\.[^\.]*$//;
	print "\t==> output file:\t" . "../$outdir/$file.html\n";
	open (OUT, '>', "../$outdir/$file.html") or die $!;
	print OUT @articlet;
	print OUT $html;					# Append content
	print OUT @articleb;
	close OUT;
}

open (OUT, '>>', "../$outdir/index.html") or die $!;		# Close all tags in index.html
print OUT @mainb;
print OUT @footer;
close OUT;

print "\nPages in pages_b/ generation completed. ";
print "\nLeaving " . getcwd . "\n";
chdir($main_dir) or die "Can't change path to $main_dir $!\n";
print "Site generation completed. Files are in output/ dir.\n";
